<p align="center">
  <img src="https://github.com/kadir014/kadir014.github.io/blob/master/assets/Heat2D%20Logo.png"><br>
  <img src="https://img.shields.io/badge/python-3%2B-green.svg">
  <img src="https://img.shields.io/badge/license-GPL%203.0-blue.svg">
  <img src="https://img.shields.io/badge/version-0.0.5-yellow">
  <img src="https://img.shields.io/badge/status-alpha-red.svg">
  <img src="https://pepy.tech/badge/heat2d">
</p>

---
Heat2D is a simple and concise 2D game engine. The main purpose of the engine is to simplify and speed-up the process of game development by providing purposive and useful tools and libraries.

Heat2D is easy to use, you can access [the documentation here](https://kadir014.github.io/projects/heat2d/index.html). You can use the API Reference, or read the getting started page and tutorials if you are a beginner.

You can join to the official [Discord Server](https://discord.gg/ctbn4Jbbr8) for further information.

## Links
- Documentation : https://kadir014.github.io/projects/heat2d/index.html
- Discord server : https://discord.gg/ctbn4Jbbr8

## License
[LGPL 3.0](LICENSE) © Kadir Aksoy
